@@ -1,7 +1,11 @@
 package App::renwd;
 
-our $DATE = '2019-10-18'; # DATE
-our $VERSION = '0.005'; # VERSION
+use strict;
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-11-15'; # DATE
+our $DIST = 'App-renwd'; # DIST
+our $VERSION = '0.006'; # VERSION
 
 1;
 # ABSTRACT: REName current (Working) Directory
@@ -18,7 +22,7 @@ App::renwd - REName current (Working) Directory
 
 =head1 VERSION
 
-This document describes version 0.005 of App::renwd (from Perl distribution App-renwd), released on 2019-10-18.
+This document describes version 0.006 of App::renwd (from Perl distribution App-renwd), released on 2021-11-15.
 
 =head1 SYNOPSIS
 
@@ -32,6 +36,42 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-renwd>
 
 Source repository is at L<https://github.com/perlancar/perl-App-renwd>.
 
+=head1 SEE ALSO
+
+L<perlmv> (from L<App::perlmv>)
+
+L<renlikewd> (from L<App::renlikewd>)
+
+L<App::RenameUtils>
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2021, 2019 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-renwd>
@@ -40,21 +80,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 SEE ALSO
-
-L<perlmv> from L<App::perlmv>
-
-L<App::RenameUtils>
-
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2019 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
